import { StorageService } from '@lightweightform/core';
import { ValidationError } from '@lightweightform/storage';
import { MarkdownService } from 'ngx-markdown';
/**
 * Service used to format validation messages' to HTML messages
 */
export declare class ValidationMessagesService {
    private _storageService;
    private _markdownService;
    constructor(_storageService: StorageService, _markdownService: MarkdownService);
    /**
     * Formats a validation error message assuming the markdown standard specification.
     * Applies some pre processors, such as:
     *
     *  - labelLink pre processor - converts a tag with format "@${path}@" to
     *  a hyperlink to the given path and a message specified in that path's
     *  component.
     * @param validationError - the validation error with
     * the preformatted  message
     * @returns - the message formatted
     */
    formatMessage(validationError: ValidationError): string;
    /**
     * Gets the label associated to the given path
     *
     * @param path - Path from which to fetch label
     * @returns - Label of given path
     */
    getLabel(path: any): string;
    private parseMD(message);
    private _applyPreProcessors(message);
    private _preProcessorLabelLinks(message);
}
